@@ -5,11 +5,11 @@ options(width=100)
 ## -------------------------------------------------------------------------------------------------
 library(biomaRt)
 
-## ----test-wormbase-ssl, echo = FALSE--------------------------------------------------------------
-if(grepl(try(httr::GET('https://parasite.wormbase.org'), silent = TRUE)[1], 
-         pattern = "sslv3 alert handshake")) {
-    httr::set_config(httr::config(ssl_cipher_list = "DEFAULT@SECLEVEL=1"))  
-}
+## ----test-wormbase-ssl, echo = FALSE, eval = FALSE------------------------------------------------
+#  if(grepl(try(httr::GET('https://parasite.wormbase.org'), silent = TRUE)[1],
+#          pattern = "sslv3 alert handshake")) {
+#     httr::set_config(httr::config(ssl_cipher_list = "DEFAULT@SECLEVEL=1"))
+#  }
 
 ## ----wormbase, echo=TRUE, eval=TRUE---------------------------------------------------------------
 listMarts(host = "parasite.wormbase.org")
